@@ -24,7 +24,6 @@ void makeCombobox1_dialog_send(void);
 void makeCombobox2_dialog_send(void);
 void send_start(void);
 void locking_start(void);
-GtkWidget *create_dialog_sendstop (int c_num);
 
 gint keyindex;
 extern Display *dpy;
@@ -75,8 +74,6 @@ GtkWidget *dialog_lock;
 GtkWidget *dialog_lock_table;
 extern GtkWidget *dialog_lock_viewport;
 
-GtkWidget *dialog_sendstop;
-
 GtkWidget *dialog_quit;
 
 GtkWidget *dialog_version;
@@ -151,10 +148,8 @@ on_main_drawingarea_configure_event        (GtkWidget       *widget,
   clientNum = draw_info[page].client_num[da_num];
   if (clientNum != EMPTY) {
     CreateImageInfo(FALSE);
-    //printf("change_rfbsock1 from:%d ",rfbsock);
-    //rfbsock = server_CB.client_grp[clientNum]->vncdsp;
-    //printf("to:%d\n",rfbsock);
-    SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum]->vncdsp);
+    draw_image(gdkpixmap[page][da_num], gdkGC, gdkimage[clientNum], 0, 0, 0, 0,
+               gdkimage[clientNum]->width, gdkimage[clientNum]->height);
   }
 
   return TRUE;
@@ -300,7 +295,7 @@ on_send_activate                       (GtkMenuItem     *menuitem,
     send_state_tmp[Cnt] = GETSEND(Cnt);
     if (server_CB.user_num == ++user_cnt) break;
   }
-  fullscreen_flag = 1;
+  fullscreen_flag = 0;	// ǥեȲ̾復ɥ
 
   dialog_send = create_dialog_send();
 
@@ -461,8 +456,8 @@ void makeTable_dialog_viewset(int pCnt)
 		      (GtkAttachOptions) (GTK_FILL), 0, 0);
   }
 
-  /* labeltab xפκ */
-  sprintf(labelname, "\343\202\277\343\203\226%d", pCnt+1);
+  /* label "tab x" */
+  sprintf(labelname, _("tab %d"), pCnt+1);
   labelTab[pCnt] = gtk_label_new (_(labelname));
   gtk_widget_show (labelTab[pCnt]);
   gtk_table_attach (GTK_TABLE (dialog_viewset_table), labelTab[pCnt], 0, 1, 2*pCnt, 2*pCnt+1,
@@ -487,8 +482,8 @@ void makeTable_dialog_viewset(int pCnt)
   gtk_widget_show (hbox_row[pCnt]);
   gtk_box_pack_start (GTK_BOX (vbox[pCnt]), hbox_row[pCnt], TRUE, TRUE, 0);
 
-  /* labelֽġפκ */
-  label_row[pCnt] = gtk_label_new (_("\347\270\246"));
+  /* label "row" */
+  label_row[pCnt] = gtk_label_new (_("row"));
   gtk_widget_show (label_row[pCnt]);
   gtk_box_pack_start (GTK_BOX (hbox_row[pCnt]), label_row[pCnt], FALSE, FALSE, 0);
 
@@ -502,8 +497,8 @@ void makeTable_dialog_viewset(int pCnt)
   gtk_widget_show (hbox_col[pCnt]);
   gtk_box_pack_start (GTK_BOX (vbox[pCnt]), hbox_col[pCnt], TRUE, TRUE, 0);
 
-  /* labelֲפκ */
-  label_col[pCnt] = gtk_label_new (_("\346\250\252"));
+  /* label "column" */
+  label_col[pCnt] = gtk_label_new (_("column"));
   gtk_widget_show (label_col[pCnt]);
   gtk_box_pack_start (GTK_BOX (hbox_col[pCnt]), label_col[pCnt], FALSE, FALSE, 0);
 
@@ -808,9 +803,7 @@ expanding_screen()
 				   server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferWidth,
 				   server_CB.client_grp[clientNum_ex]->serverInitMsg.framebufferHeight);
     gtk_label_set_text(GTK_LABEL(label_ex), server_CB.client_grp[clientNum_ex]->client_ID);
-    //rfbsock = server_CB.client_grp[clientNum_ex]->vncdsp;
     clientNum = clientNum_ex;
-    SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum_ex]->vncdsp);
   }
 }
 
@@ -830,7 +823,7 @@ GtkWidget *create_expandedwindow(void)
   /* ɥκ */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size (GTK_WINDOW(window), exwindowWidth, exwindowHeight);
-  gtk_window_set_title (GTK_WINDOW (window), _("\347\224\273\351\235\242\346\213\241\345\244\247"));
+  gtk_window_set_title (GTK_WINDOW (window), _("Expanded screen"));
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox);
@@ -845,8 +838,8 @@ GtkWidget *create_expandedwindow(void)
   gtk_widget_show (label_ex);
   gtk_box_pack_start (GTK_BOX (hbox), label_ex, TRUE, TRUE, 0);
 
-  /* toggle buttonκ */
-  window_ex_togglebutton = gtk_toggle_button_new_with_mnemonic (_("\346\223\215\344\275\234ON/OFF"));
+  /* toggle button */
+  window_ex_togglebutton = gtk_toggle_button_new_with_mnemonic (_("Operation ON/OFF"));
   gtk_widget_show (window_ex_togglebutton);
   gtk_box_pack_start (GTK_BOX (hbox), window_ex_togglebutton, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(window_ex_togglebutton), FALSE);
@@ -1066,9 +1059,9 @@ on_drawingarea_ex_configure_event      (GtkWidget       *widget,
 		     0, 0, widget->allocation.width, widget->allocation.height);
 
   CreateImageInfo(TRUE);
-  //rfbsock = server_CB.client_grp[clientNum_ex]->vncdsp;
   clientNum = clientNum_ex;
-  SendAllFramebufferUpdateRequestSpecified(server_CB.client_grp[clientNum_ex]->vncdsp);
+  draw_image(pixmap_ex, gdkGC, gdkimage[clientNum], 0, 0, 0, 0,
+             gdkimage[clientNum]->width, gdkimage[clientNum]->height);
 
   return TRUE;
 }
@@ -1135,27 +1128,27 @@ create_rightclickmenu1 (gpointer user_data)
 
   rightclickmenu1 = gtk_menu_new ();
 
-  viewset = gtk_menu_item_new_with_mnemonic (_("\350\241\250\347\244\272\350\250\255\345\256\232"));
+  viewset = gtk_menu_item_new_with_mnemonic (_("Preferences of View"));
   gtk_widget_show (viewset);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), viewset);
 
-  screen_expand = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\213\241\345\244\247"));
+  screen_expand = gtk_menu_item_new_with_mnemonic (_("Expand"));
   gtk_widget_show (screen_expand);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_expand);
 
-  screen_ctrl = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\223\215\344\275\234"));
+  screen_ctrl = gtk_menu_item_new_with_mnemonic (_("Operate"));
   gtk_widget_show (screen_ctrl);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_ctrl);
 
-  screen_lock = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\343\203\255\343\203\203\343\202\257/\350\247\243\351\231\244"));
+  screen_lock = gtk_menu_item_new_with_mnemonic (_("Lock/Unlock"));
   gtk_widget_show (screen_lock);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_lock);
 
-  screen_send = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241"));
+  screen_send = gtk_menu_item_new_with_mnemonic (_("Send screen"));
   gtk_widget_show (screen_send);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_send);
 
-  screen_send_stop = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241\345\201\234\346\255\242"));
+  screen_send_stop = gtk_menu_item_new_with_mnemonic (_("Stop sending"));
   gtk_widget_show (screen_send_stop);
   gtk_container_add (GTK_CONTAINER (rightclickmenu1), screen_send_stop);
 
@@ -1196,19 +1189,19 @@ create_rightclickmenu2 (gpointer user_data)
 
   rightclickmenu2 = gtk_menu_new ();
 
-  menuitem3 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\346\223\215\344\275\234"));
+  menuitem3 = gtk_menu_item_new_with_mnemonic (_("Operate"));
   gtk_widget_show (menuitem3);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem3);
 
-  menuitem4 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\343\203\255\343\203\203\343\202\257/\350\247\243\351\231\244"));
+  menuitem4 = gtk_menu_item_new_with_mnemonic (_("Lock/Unlock"));
   gtk_widget_show (menuitem4);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem4);
 
-  menuitem5 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241"));
+  menuitem5 = gtk_menu_item_new_with_mnemonic (_("Send screen"));
   gtk_widget_show (menuitem5);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem5);
 
-  menuitem6 = gtk_menu_item_new_with_mnemonic (_("\347\224\273\351\235\242\351\200\201\344\277\241\345\201\234\346\255\242"));
+  menuitem6 = gtk_menu_item_new_with_mnemonic (_("Stop sending screen"));
   gtk_widget_show (menuitem6);
   gtk_container_add (GTK_CONTAINER (rightclickmenu2), menuitem6);
 
@@ -1295,13 +1288,11 @@ void
 on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  int c_num = (int)user_data;
+  on_send_activate(menuitem, NULL);
 
-  if (GETRECV(c_num)) {
-    dialog_sendstop = create_dialog_sendstop(c_num);
-    gtk_widget_show(dialog_sendstop);
-    gtk_grab_add(dialog_sendstop);
-  }
+  // open 2 page
+  GtkWidget *notebook = lookup_widget(dialog_send, "notebook");
+  gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
 }
 
 
@@ -1325,7 +1316,7 @@ void makeCombobox1_dialog_send(void)
   for (pCnt = 0; pCnt < tab_num; pCnt++)
     gtk_combo_box_append_text (GTK_COMBO_BOX (dialog_send_comboboxentry1), _(draw_info[pCnt].group_name));
 
-  dialog_send_label_ID = gtk_label_new (_("\343\203\246\343\203\274\343\202\266 ID"));
+  dialog_send_label_ID = gtk_label_new (_("User ID"));
   gtk_widget_show (dialog_send_label_ID);
   gtk_box_pack_start (GTK_BOX (dialog_send_hbox), dialog_send_label_ID, FALSE, FALSE, 0);
 }
@@ -1371,8 +1362,8 @@ GtkWidget *makeTable_userList(void)
 		        (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
     }
 
-    /* label֥ xפκ */
-    sprintf(tab, "\343\202\277\343\203\226%d", pCnt+1);
+    /* label "tab x" */
+    sprintf(tab, _("tab %d"), pCnt+1);
     label = gtk_label_new (_(tab));
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2*pCnt, 2*pCnt+1,
@@ -1989,107 +1980,9 @@ void locking_start(void)
 
 
 /*******************************************************************
- *å˥塼ߤǻѤؿ
+ *MultiVNCλǧǻѤؿ
  *******************************************************************/
 
-gboolean
-on_dialog_sendstop_delete_event                (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data)
-{
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-
-  return TRUE;
-}
-
-
-void
-on_dialog_sendstop_buttonOK_clicked            (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  int c_num = (int)user_data;
-
-  SETRECV(c_num, FALSE);
-  SendCastMsg(FALSE, c_num, fullscreen_flag);
-
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-}
-
-
-void
-on_dialog_sendstop_buttonCancel_clicked        (GtkButton       *button,
-                                        gpointer         user_data)
-{
-  gtk_grab_remove(dialog_sendstop);
-  gtk_widget_destroy(dialog_sendstop);
-}
-
-
-/*
-  ߤΥåɽκ
- */
-GtkWidget*
-create_dialog_sendstop (int c_num)
-{
-  int src;
-  char message[256];
-  GtkWidget *dialog_sendstop;
-  GtkWidget *dialog_sendstop_vbox;
-  GtkWidget *label_stop;
-  GtkWidget *dialog_action_area;
-  GtkWidget *buttonOK;
-  GtkWidget *buttonCancel;
-
-  /* κ */
-  dialog_sendstop = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dialog_sendstop), _("MultiVNC \351\200\201\344\277\241\345\201\234\346\255\242\347\242\272\350\252\215"));
-  gtk_window_set_type_hint (GTK_WINDOW (dialog_sendstop), GDK_WINDOW_TYPE_HINT_DIALOG);
-
-  dialog_sendstop_vbox = GTK_DIALOG (dialog_sendstop)->vbox;
-  gtk_widget_show (dialog_sendstop_vbox);
-
-  /* åɽlabelκ */
-  src = server_CB.cast_src[server_CB.client_grp[c_num]->recv_grp];
-  sprintf(message, "%s\343\201\213\343\202\211\n%s\343\201\270\343\201\256\351\200\201\344\277\241\343\202\222\345\201\234\346\255\242\343\201\227\343\201\276\343\201\231\343\201\213\357\274\237", server_CB.client_grp[src]->client_ID, server_CB.client_grp[c_num]->client_ID);
-  label_stop = gtk_label_new (_(message));
-  gtk_widget_show (label_stop);
-  gtk_box_pack_start (GTK_BOX (dialog_sendstop_vbox), label_stop, FALSE, FALSE, 0);
-
-  dialog_action_area = GTK_DIALOG (dialog_sendstop)->action_area;
-  gtk_widget_show (dialog_action_area);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
-
-  /* OKܥκ */
-  buttonOK = gtk_button_new_from_stock ("gtk-ok");
-  gtk_widget_show (buttonOK);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog_sendstop), buttonOK, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (buttonOK, GTK_CAN_DEFAULT);
-
-  /* Cancelܥκ */
-  buttonCancel = gtk_button_new_from_stock ("gtk-cancel");
-  gtk_widget_show (buttonCancel);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog_sendstop), buttonCancel, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS (buttonCancel, GTK_CAN_DEFAULT);
-
-  g_signal_connect ((gpointer) dialog_sendstop, "delete_event",
-                    G_CALLBACK (on_dialog_sendstop_delete_event),
-                    NULL);
-
-  g_signal_connect ((gpointer) buttonOK, "clicked",
-                    G_CALLBACK (on_dialog_sendstop_buttonOK_clicked),
-                    (gpointer)c_num);
-
-  g_signal_connect ((gpointer) buttonCancel, "clicked",
-                    G_CALLBACK (on_dialog_sendstop_buttonCancel_clicked),
-                    NULL);
-
-  return dialog_sendstop;
-}
-
-
-
 gboolean
 on_dialog_quit_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -2123,6 +2016,10 @@ on_dialog_quit_buttonCancel_clicked    (GtkButton       *button,
 }
 
 
+/*******************************************************************
+ *СɽǻѤؿ
+ *******************************************************************/
+
 gboolean
 on_dialog_version_delete_event         (GtkWidget       *widget,
                                         GdkEvent        *event,
