@@ -213,7 +213,7 @@ AdvInit ()
 int
 ConnectMyself ()
 {
-  char tmp[64] = "multivnc_client -d 1 -u ";
+  char tmp[64] = "multivnc_client -d 1 --nonotice -u ";
   strcat (tmp, server_CB.server_ID);
   strcat (tmp, " &");
   printf("tmp=%s\n",tmp);
