@@ -7,6 +7,7 @@
 #include <resolv.h>
 #include <errno.h>
 #include <time.h>
+#include <getopt.h>
 
 #include "vncviewer.h"
 #include <jpeglib.h>
@@ -36,6 +37,7 @@ char answer;
 int lock_time = 0;
 gint lock_tag;
 int auto_flag = 0;
+int notice_flag = 1;
 GtkWidget *drawing_window;
 GtkWidget *dialog_IDinput;
 GtkWidget *dialog_wait;
@@ -45,7 +47,6 @@ GtkWidget *lock_window;
 GtkWidget *mini_window;
 extern GtkWidget *client_drawingarea;
 extern GtkWidget *screen_label;
-extern GtkWidget *recvAdv_label;
 
 /****/
 #define BGR233_SIZE 256
@@ -239,17 +240,33 @@ JpegSetSrcManager(j_decompress_ptr cinfo, CARD8 *compressedData,
 #include "mtight.c"
 #undef BPP
 
+#define OPTNUM 2
 
 
 int client_main(int argc, char **argv)
 {   
   int errno;
-  int c;
+  int c, option_index;
+  struct option *options;
+  
+  options = malloc(sizeof(struct option) * OPTNUM);
+  options[0].name = "nonotice";
+  options[0].has_arg = no_argument;
+  options[0].flag = NULL;
+  options[0].val = 1;
+  options[1].name = 0;
+  options[1].has_arg = 0;
+  options[1].flag = 0;
+  options[1].val = 0;
 
   /* command line check */
   programName = argv[0];
-  while ((c = getopt(argc, argv, "d:u:fh")) != EOF) {
+  while ((c = getopt_long(argc, argv, "d:u:fh", options, &option_index)) != EOF) {
+//  while ((c = getopt(argc, argv, "d:u:fnh")) != EOF) {
     switch (c) {
+      case 1:
+	notice_flag = 0;
+	break;
       case 'd':
 	vncdisplay = optarg;
 	break;
@@ -269,7 +286,7 @@ int client_main(int argc, char **argv)
   /* start vncserver */
   StartVNCServer();
 
-  if (auto_flag == 0) {
+  if (notice_flag == 1) {
     mini_window = (GtkWidget *)create_mini_window();
     gtk_widget_show(mini_window);
   }
@@ -382,7 +399,7 @@ JoinVNC () {
   fprintf (stdout, "%s\n", commandvnc2);
   fprintf (stdout, "%s\n", commandvnc3);
 
-  /* exeute vncconnect */
+  /* execute vncconnect */
   client_CB.vncdsp = system(commandvnc1);
   client_CB.vncdsp = system(commandvnc2);
   client_CB.vncdsp = system(commandvnc3);
@@ -459,15 +476,16 @@ MultiRecieve1 ()
   int addr_len = sizeof(recvadd);
   int numrcv;
   ServerAdv serveradv;
-  char recvAdv_msg[256];
 
   bzero(&serveradv, sizeof(ServerAdv));
   numrcv = recvfrom(client_CB.mltdsp, &serveradv, sizeof(ServerAdv), 0, \
       		    (struct sockaddr *)&recvadd, (int *)&addr_len);
   memcpy(client_CB.server_ID, serveradv.server_ID, 16);
   if (auto_flag) {
-    client_CB.server_ip = inet_addr(SERVER_IP);
-    client_CB.server_port = htons(SERVER_PORT);
+    //client_CB.server_ip = inet_addr(SERVER_IP);
+    //client_CB.server_port = htons(SERVER_PORT);
+    client_CB.server_ip = recvadd.sin_addr.s_addr;
+    client_CB.server_port = serveradv.server_port;
   } else {
     client_CB.server_ip = recvadd.sin_addr.s_addr;
     client_CB.server_port = serveradv.server_port;
@@ -488,12 +506,9 @@ MultiRecieve1 ()
 
   if (auto_flag == 0) {
     draw_string_to_mini_window("Connect?");
-    dialog_recvAdv = (GtkWidget *)create_dialog_recvAdv();
-    sprintf(recvAdv_msg, "\343\202\265\343\203\274\343\203\220%s\343\201\213\343\202\211\343\201\256\n\346\216\245\347\266\232\350\246\201\346\261\202\343\202\222\345\217\227\344\277\241\343\201\227\343\201\276\343\201\227\343\201\237\343\200\202\n\n\346\216\245\347\266\232\343\201\227\343\201\276\343\201\231\343\201\213?", serveradv.server_ID);
-    gtk_label_set_text(GTK_LABEL(recvAdv_label), recvAdv_msg);
-    gtk_widget_show(dialog_recvAdv);
-    gtk_grab_add(dialog_recvAdv);
-    gtk_main();
+    open_dialog_recvAdv(serveradv.server_ID);
+  } else {
+    draw_string_to_mini_window("Connect");
   }
 
   if (((answer == 'y') || (auto_flag == 1)) && JoinCTL ()) {
@@ -596,16 +611,25 @@ GetMultiVNCServerMsg (void *g_dsp)
 	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
 	  if ((buf[1] == 1) && (!GETRECV_C)) {
 	    SETRECV_C(1);
-	    draw_string_to_mini_window("Receive Data");
-	    drawing_window = (GtkWidget *)create_drawing_window();
-
-	    gtk_label_set_text(GTK_LABEL(screen_label), castadv.src_ID);
-
-	    drawingarea[0][0] = client_drawingarea;
 	    client_CB.casting_ip = castadv.casting_ip;
 	    client_CB.casting_port = castadv.casting_port;
 	    memcpy (&client_CB.serverInitMsg, &castadv.serverInitMsg, sizeof(rfbServerInitMsg));
 	    memcpy(&si, &client_CB.serverInitMsg, sizeof(rfbServerInitMsg));
+	    draw_string_to_mini_window("Receive Data");
+	    if (gdkimage[0] == NULL) {
+	      gdkimage[0] = gdk_image_new(GDK_IMAGE_FASTEST, gdkvis,
+				client_CB.serverInitMsg.framebufferWidth, client_CB.serverInitMsg.framebufferHeight);
+	    }
+	    if (smallimage[0] == NULL) {
+	      smallimage[0] = gdk_image_new(GDK_IMAGE_FASTEST, gdkvis,
+				client_CB.serverInitMsg.framebufferWidth, client_CB.serverInitMsg.framebufferHeight);
+	    }
+	    drawing_window = (GtkWidget *)create_drawing_window();
+	    gtk_window_set_default_size(GTK_WINDOW(drawing_window), 600, 400);
+
+	    gtk_label_set_text(GTK_LABEL(screen_label), castadv.src_ID);
+
+	    drawingarea[0][0] = client_drawingarea;
 	    printf("ip=%s, port=%d\n",(char *)inet_ntoa(client_CB.casting_ip), \
 							ntohs(client_CB.casting_port));
             client_CB.cstdsp = CreateMultiSockToRecv ((char *)inet_ntoa(client_CB.casting_ip), \
@@ -616,6 +640,8 @@ GetMultiVNCServerMsg (void *g_dsp)
 		                                (GdkInputFunction)GetMultiVNCServerMsg, \
 						(gpointer)client_CB.cstdsp);
 	    gtk_widget_show(drawing_window);
+	    if (castadv.fullscreen)
+	      gdk_window_fullscreen(gdk_window_get_toplevel(drawing_window->window));
 	    DrawingInit();
 	  } else if ((buf[1] == 0) && (GETRECV_C)) {
 	    SETRECV_C(0);
@@ -624,6 +650,9 @@ GetMultiVNCServerMsg (void *g_dsp)
 	    gdk_image_destroy(gdkimage[0]);
 	    gdk_image_destroy(smallimage[0]);
 	    gtk_widget_destroy(drawing_window);
+	    gdkimage[0] = NULL;
+	    smallimage[0] = NULL;
+	    drawing_window = NULL;
 	    draw_string_to_mini_window("Connect");
 	  } 
 	}
@@ -649,7 +678,7 @@ GetMultiVNCServerMsg (void *g_dsp)
 	      start_lock();
 	      gtk_timeout_remove (lock_tag);
 	    }
-	    lock_tag = gtk_timeout_add((lockadv.locktime + 2) * 1000, stop_lock, NULL);
+	    lock_tag = gtk_timeout_add((lockadv.locktime + 10) * 1000, stop_lock, NULL);
 	  } else {
 	    gtk_timeout_remove (lock_tag);
 	    stop_lock();
@@ -1019,8 +1048,9 @@ void
 help (char *cmd)
 {
   fprintf(stderr, "\nmultivnc_client\n");
-  fprintf(stderr, "  -d [num]:display number of vncserver\n\n");
-  fprintf(stderr, "  -u [user_name]:Input client id and auto connect.\n\n");
+  fprintf(stderr, "  -d [num]\t\tDisplay number of vncserver\n\n");
+  fprintf(stderr, "  -u [user_name]\tInput client ID and auto connect.\n\n");
+  fprintf(stderr, "  --nonotice\t\tState window is not displayed.\n\n");
 }
 
 void
